@@ -23,5 +23,8 @@ LV2_SYMBOL_EXPORT
 const LV2_Lib_Descriptor*
 lv2_lib_descriptor(const char* bundle_path, const LV2_Feature* const* features)
 {
+  (void)bundle_path;
+  (void)features;
+
   return NULL;
 }
