@@ -1,6 +1,6 @@
 /*
   Lilv Test Plugin - Missing name
-  Copyright 2011-2015 David Robillard <d@drobilla.net>
+  Copyright 2011-2019 David Robillard <d@drobilla.net>
 
   Permission to use, copy, modify, and/or distribute this software for any
   purpose with or without fee is hereby granted, provided that the above
@@ -15,42 +15,40 @@
   OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */
 
-#include <stdlib.h>
+#include "lv2/core/lv2.h"
 
-#include "lv2/lv2plug.in/ns/lv2core/lv2.h"
+#include <stdint.h>
+#include <stdlib.h>
 
 #define PLUGIN_URI "http://example.org/missing-name"
 
-enum {
-	TEST_INPUT  = 0,
-	TEST_OUTPUT = 1
-};
+enum { TEST_INPUT = 0, TEST_OUTPUT = 1 };
 
 typedef struct {
-	float* input;
-	float* output;
+  float* input;
+  float* output;
 } Test;
 
 static void
 cleanup(LV2_Handle instance)
 {
-	free((Test*)instance);
+  free((Test*)instance);
 }
 
 static void
 connect_port(LV2_Handle instance, uint32_t port, void* data)
 {
-	Test* test = (Test*)instance;
-	switch (port) {
-	case TEST_INPUT:
-		test->input = (float*)data;
-		break;
-	case TEST_OUTPUT:
-		test->output = (float*)data;
-		break;
-	default:
-		break;
-	}
+  Test* test = (Test*)instance;
+  switch (port) {
+  case TEST_INPUT:
+    test->input = (float*)data;
+    break;
+  case TEST_OUTPUT:
+    test->output = (float*)data;
+    break;
+  default:
+    break;
+  }
 }
 
 static LV2_Handle
@@ -59,35 +57,43 @@ instantiate(const LV2_Descriptor*     descriptor,
             const char*               path,
             const LV2_Feature* const* features)
 {
-	Test* test = (Test*)calloc(1, sizeof(Test));
-	if (!test) {
-		return NULL;
-	}
+  (void)descriptor;
+  (void)rate;
+  (void)path;
+  (void)features;
 
-	return (LV2_Handle)test;
+  Test* test = (Test*)calloc(1, sizeof(Test));
+  if (!test) {
+    return NULL;
+  }
+
+  return (LV2_Handle)test;
 }
 
 static void
 run(LV2_Handle instance, uint32_t sample_count)
 {
-	Test* test = (Test*)instance;
+  (void)sample_count;
 
-	*test->output = *test->input;
+  Test* test = (Test*)instance;
+
+  *test->output = *test->input;
 }
 
 static const LV2_Descriptor descriptor = {
-	PLUGIN_URI,
-	instantiate,
-	connect_port,
-	NULL, // activate,
-	run,
-	NULL, // deactivate,
-	cleanup,
-	NULL  // extension_data
+  PLUGIN_URI,
+  instantiate,
+  connect_port,
+  NULL, // activate,
+  run,
+  NULL, // deactivate,
+  cleanup,
+  NULL // extension_data
 };
 
 LV2_SYMBOL_EXPORT
-const LV2_Descriptor* lv2_descriptor(uint32_t index)
+const LV2_Descriptor*
+lv2_descriptor(uint32_t index)
 {
-	return (index == 0) ? &descriptor : NULL;
+  return (index == 0) ? &descriptor : NULL;
 }
